<?php
/**
 * @file
 * Administrative page callbacks for the Rasalas module.
 */

/**
 * Rasalas settings form.
 */
function rasalas_admin_settings_form($form_state)
{
    $form = array();

    $settings = rasalas_get_settings();
    $form['rasalas_script_id'] = array(
        '#parents' => array('rasalas_settings', 'rasalas_script_id'),
        '#title' => t('tap4call id'),
        '#type' => 'textfield',
        '#default_value' => $settings['rasalas_script_id'],
        '#size' => 36,
        '#maxlength' => 36,
        '#required' => TRUE,
        '#description' => t('Proszę podać swój tap4call id.'),
    );

    $form['associacion'] = array(
        '#type' => 'vertical_tabs',
    );

    $visibility = $settings['rasalas_visibility_pages'];
    $pages = $settings['rasalas_pages'];

    $form['association']['page_script'] = array(
        '#type' => 'fieldset',
        '#title' => t('Pages'),
        '#collapsible' => TRUE,
        '#collapsed' => TRUE,
    );

    if ($visibility == 2) {
        $form['association']['page_script'] = array();
        $form['association']['page_script']['rasalas_visibility_pages'] = array('#type' => 'value', '#value' => 2);
        $form['association']['page_script']['rasalas_pages'] = array('#type' => 'value', '#value' => $pages);
    } else {
        $options = array(
            t('Every page except the listed pages'),
            t('The listed pages only'),
        );
        $description_args = array(
            '%blog' => 'blog',
            '%blog-wildcard' => 'blog/*',
            '%front' => '<front>',
        );
        $description = t("Specify pages by using their paths. Enter one path per line. The '*' character is a wildcard. Example paths are %blog for the blog page and %blog-wildcard for every personal blog. %front is the front page.", $description_args);
        $title = t('Pages');
        $form['association']['page_script']['rasalas_visibility_pages'] = array(
            '#parents' => array('rasalas_settings', 'rasalas_visibility_pages'),
            '#type' => 'radios',
            '#title' => t('Add script to specific pages'),
            '#options' => $options,
            '#default_value' => $visibility,
        );
        $form['association']['page_script']['rasalas_pages'] = array(
            '#parents' => array('rasalas_settings', 'rasalas_pages'),
            '#type' => 'textarea',
            '#title' => $title,
            '#title_display' => 'invisible',
            '#default_value' => $pages,
            '#description' => $description,
            '#rows' => 10,
        );
    }

    // Render the role overview.
    $form['association']['role_script'] = array(
        '#type' => 'fieldset',
        '#title' => t('Roles'),
    );

    $form['association']['role_script']['rasalas_visibility_roles'] = array(
        '#parents' => array('rasalas_settings', 'rasalas_visibility_roles'),
        '#type' => 'radios',
        '#title' => t('Add script for specific roles'),
        '#options' => array(
            t('Add to the selected roles only'),
            t('Add to every role except the selected ones'),
        ),
        '#default_value' => $settings['rasalas_visibility_roles'],
    );

    $role_options = array_map('check_plain', user_roles());
    $form['association']['role_script']['rasalas_roles'] = array(
        '#parents' => array('rasalas_settings', 'rasalas_roles'),
        '#type' => 'checkboxes',
        '#title' => t('Roles'),
        '#default_value' => $settings['rasalas_roles'],
        '#options' => $role_options,
        '#description' => t('If none of the roles are selected, all users will have enabled script. If a user has any of the roles checked, that user will have enabled script (or excluded, depending on the setting above).'),
    );

    return system_settings_form($form);
}
